##  Exporting Transformation Items to Excel
In the transformations explorer, both admin and non-admin users can export transformation items to an Excel spreadsheet. You can export all items or use filters to export a specific subset. This helps you access transformation data easily, whether you work in the tool or need to share data with other teams.
To export, do the following:
  1. To narrow down the transformation items you want to export, apply filters such as those linked to a specific initiative, status, or transformation types.
  2. Choose Export to Excel icon at the top right corner of the table.
![Exporting to Excel from the Transformations Explorer](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiofc3bcc4ae31e4fcc8d2cb5629ac0d837_LowRes.png)
Exporting to Excel from the Transformations Explorer
  3. In the confirmation dialog box, choose Export.


**Note**
Currently, you cannot export transformation items by selecting them individually.
